@@ -24,12 +24,14 @@ class CLI(cl1.CLI):
 		# cli.
 		cl1.CLI.__init__(self,
 			modes={
+				"--encrypt /path/to/input /path/to/output":"Encrypt the provided file path.",
+				"--decrypt /path/to/input /path/to/output":"Decrypt the provided file path.",
 				"--generate-keys":"Generate a key pair.",
-				"--encrypt /path/to/file":"Encrypt the provided file path.",
-				"--decrypt /path/to/file":"Decrypt the provided file path.",
+				"--generate-passphrase --length 32":"Generate a passphrase.",
 				"-h / --help":"Show the documentation.",
 			},
 			options={
+				"--remove":"Remove the input file.",
 				"--key /path/to/directory/":"Specify the path to the key's directory.",
 				"--public-key /path/to/directory/public_key":"Specify the path to the public key.",
 				"--private-key /path/to/directory/private_key":"Specify the path to the private key.",
@@ -47,23 +49,32 @@ class CLI(cl1.CLI):
 
 		# encrypt.
 		elif self.argument_present('--encrypt'):
-			file = self.get_argument('--encrypt')
+			input = self.get_argument('--encrypt', index=1)
+			output = self.get_argument('--encrypt', index=2)
 			encryption = self.get_encryption()
-			encryption.load_public_key()
-			#if os.path.isdir(file): 
-			response = encryption.encrypt(file, layers=layers, recursive=True)
-			#else: encryption.encrypt_file(file, layers=layers)
+			response = encryption.load_public_key()
+			r3sponse.log(response=response)
+			if not r3sponse.success(response): sys.exit(1)
+			if os.path.isdir(input): 
+				raise ValueError("COMING SOON.")
+				response = encryption.encrypt_directory(input=input, output=output, remove=self.argument_present("--remove"))
+			else: 
+				response = encryption.encrypt_file(input=input, output=output, remove=self.argument_present("--remove"))
 			r3sponse.log(response=response)
 
 		# decrypt.
 		elif self.argument_present('--decrypt'):
-			file = self.get_argument('--decrypt')
-			file = self.get_argument('--encrypt')
+			input = self.get_argument('--decrypt', index=1)
+			output = self.get_argument('--decrypt', index=2)
 			encryption = self.get_encryption()
-			encryption.load_private_key()
-			#if os.path.isdir(file): 
-			response = encryption.decrypt(file, layers=layers, recursive=True)
-			#else: encryption.decrypt_file(file, layers=layers)
+			response = encryption.load_private_key()
+			r3sponse.log(response=response)
+			if not r3sponse.success(response): sys.exit(1)
+			if os.path.isdir(input): 
+				raise ValueError("COMING SOON.")
+				response = encryption.decrypt_directory(input=input, output=output, remove=self.argument_present("--remove"))
+			else: 
+				response = encryption.decrypt_file(input=input, output=output, remove=self.argument_present("--remove"))
 			r3sponse.log(response=response)
 
 		# generate-keys.
@@ -72,6 +83,11 @@ class CLI(cl1.CLI):
 			response = encryption.generate_keys()
 			r3sponse.log(response=response)
 
+		# generate passphrase.
+		elif self.argument_present('--generate-passphrase'):
+			length = int(self.get_argument('--length', required=False, empty=32))
+			print("Generated passphrase:",Formats.String("").generate(length=length, capitalize=True, digits=True))
+
 		# invalid.
 		else: 
 			print(self.documentation)
