@@ -93,7 +93,7 @@ class AssymetricAES(object):
 		return self.rsa.load_private_key()
 	def load_public_key(self):
 		return self.rsa.load_public_key()
-	def encrypt(self, string):
+	def encrypt(self, string, decode=False):
 		if isinstance(string, bytes):
 			string = string.decode()
 		
@@ -107,7 +107,7 @@ class AssymetricAES(object):
 			return r3sponse.error_response("AES encrypt data contains invalid ' ' character(s).")
 
 		# encrypt aes key with rsa.
-		response = self.rsa.encrypt(passphrase)
+		response = self.rsa.encrypt_string(passphrase, decode=False)
 		if not r3sponse.success(response): return response
 		rsa_encrypted = response["encrypted"]
 
@@ -115,12 +115,13 @@ class AssymetricAES(object):
 		encrypted = rsa_encrypted+b" "+aes_encrypted
 
 		# success.
+		if decode: encrypted = encrypted.decode()
 		return r3sponse.success_response("Successfully encrypted the specified data.", {
 			"encrypted":encrypted
 		})
 
 		#
-	def decrypt(self, string):
+	def decrypt(self, string, decode=False):
 
 		# split encrypted aes key.
 		if isinstance(string, bytes):
@@ -132,7 +133,7 @@ class AssymetricAES(object):
 			return r3sponse.error_response("Unable to unpack the encrypted data.")
 
 		# decypt key with rsa.
-		response = self.rsa.decrypt(key)
+		response = self.rsa.decrypt_string(key, decode=False)
 		if not r3sponse.success(response): return response
 		passphrase = response["decrypted"].decode()
 
@@ -143,10 +144,63 @@ class AssymetricAES(object):
 		decrypted = response["decrypted"]
 
 		# success.
+		if decode: decrypted = decrypted.decode()
 		return r3sponse.success_response("Successfully decrypted the specified data.", {
 			"decrypted":decrypted
 		})
 
+		#
+	def encrypt_file(self, input=None, output=None, remove=False):
+		
+
+		# check params.
+		response = r3sponse.check_parameters({
+			"input":input,
+			"output":output,})
+		if not r3sponse.success(response): return response
+
+		# encrypt.
+		response = self.encrypt(utils.__load_file__(input), decode=False)
+		if not r3sponse.success(response): return response
+
+		# write out.
+		try: utils.__save_bytes__(output, response["encrypted"])
+		except: return r3sponse.success_response(f"Failed to write out encrypted file {output}.")
+
+		# remove.
+		if remove: 
+			try: os.remove(input)
+			except PermissionError: os.system(f"sudo rm -fr {input}")
+
+		# handler.
+		return r3sponse.success_response(f"Successfully encrypted file {intput} to {output}.")
+
+		#
+	def decrypt_file(self, input=None, output=None, remove=False):
+		
+
+		# check params.
+		response = r3sponse.check_parameters({
+			"input":input,
+			"output":output,})
+		if not r3sponse.success(response): return response
+
+		# encrypt.
+		response = self.decrypt(utils.__load_file__(input), decode=False)
+		if not r3sponse.success(response): return response
+
+		# write out.
+		try: utils.__save_bytes__(output, response["decrypted"])
+		except: return r3sponse.success_response(f"Failed to write out decrypted file {output}.")
+
+		# remove.
+		if remove: 
+			try: os.remove(input)
+			except PermissionError: os.system(f"sudo rm -fr {input}")
+
+		# handler.
+		return r3sponse.success_response(f"Successfully decrypted file {intput} to {output}.")
+
 		#
 
 # initialize. 
